TERMINAL_STATUSES = {"COMPLETED", "ERRORED", "CANCELED", "TIMEOUT", "FAILED"}

API_URL_TO_USER_URL_MAP = {
    "https://dev-api.vijil.ai/v1": "https://dev.vijil.ai",
    "https://stage-api.vijil.ai/v1": "https://stage.vijil.ai",
    "https://evaluate-api.vijil.ai/v1": "https://evaluate.vijil.ai",
}
